@@ -5,7 +5,7 @@
 """
 
 from typing import List
-from sqlite3_api.example.my_tables import Students, Points
+from sqlite3_api.example.my_tables import Students, Points, Position
 
 # Используем 1-й способ инициализации
 students = Students('example.db')  # Инициализируем таблицу `Students`
@@ -117,6 +117,11 @@ obj.position += (0.8, 3.1)
 print(f'{obj.position=}')
 print(f'{obj.save()=}')
 
+print('\n      Изменим позицию второй точки')
+obj = points.filter(id=2)
+obj.position = Position(2, 10)
+print(f'{obj.save()=}')
+
 print('\n      Посмотрим на таблицу в целом')
 for obj in points.filter(return_list=True):
     print(obj, '\n')
