@@ -19,10 +19,10 @@ NEXT: create_database.py
 
 from __future__ import annotations
 from sqlite3_api.Table import Table
-from sqlite3_api.types import List
+from sqlite3_api.field_types import List
 
 # Инструмент для создания новых типов данных
-from sqlite3_api.types import CustomType
+from sqlite3_api.field_types import CustomType
 
 
 class Students(Table):
@@ -33,7 +33,7 @@ class Students(Table):
     # Поле `course`. Тип данных: integer. Значение по умолчанию: 1
     course: int = 1
     salary: int = 5000
-    marks: List = []
+    marks: List = List([])
 
 
 """
@@ -89,7 +89,7 @@ class Position(CustomType):
         в каком они будут храниться в таблице.
         """
 
-        return ('%f;%f' % (obj.x, obj.y)).encode('ascii')
+        return ('%f;%f' % (obj.x, obj.y)).encode()
 
     def converter(self, obj: bytes) -> Position:
         """
